.. _network_advanced:

***************************************************
Advanced Topics with Ansible for Network Automation
***************************************************

Once you have mastered the basics of network automation with Ansible, as presented in :ref:`network_getting_started`, use this guide understand platform-specific details, optimization, and troubleshooting tips for Ansible for network automation.

**Who should use this guide?**

This guide is intended for network engineers using Ansible for automation. It covers advanced topics. If you understand networks and Ansible, this guide is for you. You may read through the entire guide if you choose, or use the links below to find the specific information you need.

If you're new to Ansible, or new to using Ansible for network automation, start with the :ref:`network_getting_started`.

.. toctree::
   :maxdepth: 2
   :caption: Advanced Topics

   faq
   network_best_practices_2.5
   network_debug_troubleshooting
   network_working_with_command_output
   platform_index
